package com.bonus.canteen.core.supply.service.impl;

import java.util.List;
import com.bonus.common.core.exception.ServiceException;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.canteen.core.supply.mapper.SupplyProductUnitMapper;
import com.bonus.canteen.core.supply.domain.SupplyProductUnit;
import com.bonus.canteen.core.supply.service.ISupplyProductUnitService;

/**
 * 计量单位Service业务层处理
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Service
public class SupplyProductUnitServiceImpl implements ISupplyProductUnitService {
    @Autowired
    private SupplyProductUnitMapper supplyProductUnitMapper;

    /**
     * 查询计量单位
     * 
     * @param unitId 计量单位主键
     * @return 计量单位
     */
    @Override
    public SupplyProductUnit selectSupplyProductUnitByUnitId(Long unitId) {
        return supplyProductUnitMapper.selectSupplyProductUnitByUnitId(unitId);
    }

    /**
     * 查询计量单位列表
     * 
     * @param supplyProductUnit 计量单位
     * @return 计量单位
     */
    @Override
    public List<SupplyProductUnit> selectSupplyProductUnitList(SupplyProductUnit supplyProductUnit) {
        return supplyProductUnitMapper.selectSupplyProductUnitList(supplyProductUnit);
    }

    /**
     * 新增计量单位
     * 
     * @param supplyProductUnit 计量单位
     * @return 结果
     */
    @Override
    public int insertSupplyProductUnit(SupplyProductUnit supplyProductUnit) {
        supplyProductUnit.setCreateTime(DateUtils.getNowDate());
        try {
            return supplyProductUnitMapper.insertSupplyProductUnit(supplyProductUnit);
        } catch (Exception e) {
            throw new ServiceException(e.getMessage());
        }
    }

    /**
     * 修改计量单位
     * 
     * @param supplyProductUnit 计量单位
     * @return 结果
     */
    @Override
    public int updateSupplyProductUnit(SupplyProductUnit supplyProductUnit) {
        supplyProductUnit.setUpdateTime(DateUtils.getNowDate());
        try {
            return supplyProductUnitMapper.updateSupplyProductUnit(supplyProductUnit);
        } catch (Exception e) {
            throw new ServiceException(e.getMessage());
        }
    }

    /**
     * 批量删除计量单位
     * 
     * @param unitIds 需要删除的计量单位主键
     * @return 结果
     */
    @Override
    public int deleteSupplyProductUnitByUnitIds(Long[] unitIds) {
        return supplyProductUnitMapper.deleteSupplyProductUnitByUnitIds(unitIds);
    }

    /**
     * 删除计量单位信息
     * 
     * @param unitId 计量单位主键
     * @return 结果
     */
    @Override
    public int deleteSupplyProductUnitByUnitId(Long unitId) {
        return supplyProductUnitMapper.deleteSupplyProductUnitByUnitId(unitId);
    }
}
