package com.bonus.canteen.core.supply.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supply.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supply.domain.SupplyProductUnit;
import com.bonus.canteen.core.supply.service.ISupplyProductUnitService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 计量单位Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "计量单位接口")
@RestController
@RequestMapping("/supply_product_unit")
public class SupplyProductUnitController extends BaseController {
    @Autowired
    private ISupplyProductUnitService supplyProductUnitService;

    /**
     * 查询计量单位列表
     */
    @ApiOperation(value = "查询计量单位列表")
    //@RequiresPermissions("supply:unit:list")
    @GetMapping("/list")
    public TableDataInfo list(SupplyProductUnit supplyProductUnit) {
        startPage();
        List<SupplyProductUnit> list = supplyProductUnitService.selectSupplyProductUnitList(supplyProductUnit);
        return getDataTable(list);
    }

    /**
     * 导出计量单位列表
     */
    @ApiOperation(value = "导出计量单位列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:unit:export")
    @SysLog(title = "计量单位", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出计量单位")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupplyProductUnit supplyProductUnit) {
        List<SupplyProductUnit> list = supplyProductUnitService.selectSupplyProductUnitList(supplyProductUnit);
        ExcelUtil<SupplyProductUnit> util = new ExcelUtil<SupplyProductUnit>(SupplyProductUnit.class);
        util.exportExcel(response, list, "计量单位数据");
    }

    /**
     * 获取计量单位详细信息
     */
    @ApiOperation(value = "获取计量单位详细信息")
    //@RequiresPermissions("supply:unit:query")
    @GetMapping(value = "/{unitId}")
    public AjaxResult getInfo(@PathVariable("unitId") Long unitId) {
        return success(supplyProductUnitService.selectSupplyProductUnitByUnitId(unitId));
    }

    /**
     * 新增计量单位
     */
    @ApiOperation(value = "新增计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:unit:add")
    @SysLog(title = "计量单位", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增计量单位")
    @PostMapping
    public AjaxResult add(@RequestBody SupplyProductUnit supplyProductUnit) {
        try {
            return toAjax(supplyProductUnitService.insertSupplyProductUnit(supplyProductUnit));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改计量单位
     */
    @ApiOperation(value = "修改计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:unit:edit")
    @SysLog(title = "计量单位", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改计量单位")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupplyProductUnit supplyProductUnit) {
        try {
            return toAjax(supplyProductUnitService.updateSupplyProductUnit(supplyProductUnit));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除计量单位
     */
    @ApiOperation(value = "删除计量单位")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supply:unit:remove")
    @SysLog(title = "计量单位", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除计量单位")
	@PostMapping("/del/{unitIds}")
    public AjaxResult remove(@PathVariable Long[] unitIds) {
        return toAjax(supplyProductUnitService.deleteSupplyProductUnitByUnitIds(unitIds));
    }
}
